@@ -1,14 +1,14 @@
-{-# LANGUAGE CPP #-}
-{-# OPTIONS_GHC -fno-warn-orphans #-}
+{-# OPTIONS_GHC -Wno-orphans #-}
 {-|
 Module:      TextShow.Data.List
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
 Portability: GHC
 
-Exports 'showbListWith', 'showtListWith', and 'showtlListWith'.
+Exports 'showbListWith', 'showtListWith', and 'showtlListWith',
+and 'TextShow' instances for lists.
 -}
 module TextShow.Data.List (showbListWith, showtListWith, showtlListWith) where
 
@@ -16,15 +16,15 @@ import TextShow.Classes (TextShow(..), TextShow1(..), showbListWith, showtListWi
 import TextShow.Data.Char ()
 import TextShow.Data.Integral ()
 
-#include "inline.h"
-
+-- | /Since: 2/
 instance TextShow a => TextShow [a] where
     {-# SPECIALIZE instance TextShow [String] #-}
     {-# SPECIALIZE instance TextShow String   #-}
     {-# SPECIALIZE instance TextShow [Int]    #-}
     showb = showbList
-    INLINE_INST_FUN(showb)
+    {-# INLINE showb #-}
 
+-- | /Since: 2/
 instance TextShow1 [] where
     liftShowbPrec _ sl _ = sl
-    INLINE_INST_FUN(liftShowbPrec)
+    {-# INLINE liftShowbPrec #-}
