@@ -1,9 +1,7 @@
 {-# LANGUAGE CPP              #-}
-{-# LANGUAGE TemplateHaskell  #-}
-#if MIN_VERSION_base(4,8,0)
 {-# LANGUAGE FlexibleContexts #-}
-#endif
-{-# OPTIONS_GHC -fno-warn-orphans #-}
+{-# LANGUAGE TemplateHaskell  #-}
+{-# OPTIONS_GHC -Wno-orphans #-}
 {-|
 Module:      TextShow.Data.Monoid
 Copyright:   (C) 2014-2017 Ryan Scott
@@ -18,17 +16,12 @@ Portability: GHC
 -}
 module TextShow.Data.Monoid () where
 
-import Data.Monoid.Compat (All, Any, Dual, First, Last, Product, Sum)
+import Data.Monoid (All, Alt, Any, Dual, First, Last, Product, Sum)
 
+import TextShow.Classes (TextShow(..))
 import TextShow.Data.Bool ()
 import TextShow.Data.Maybe ()
-import TextShow.TH.Internal (deriveTextShow, deriveTextShow1)
-
-#if MIN_VERSION_base(4,8,0)
-import Data.Monoid (Alt)
-import TextShow.Classes (TextShow(..))
-import TextShow.TH.Internal (makeShowbPrec)
-#endif
+import TextShow.TH.Internal (deriveTextShow, deriveTextShow1, makeShowbPrec)
 
 #if MIN_VERSION_base(4,12,0)
 import Data.Monoid (Ap)
@@ -59,18 +52,12 @@ $(deriveTextShow  ''Sum)
 -- | /Since: 2/
 $(deriveTextShow1 ''Sum)
 
-#if MIN_VERSION_base(4,8,0)
--- | Only available with @base-4.8.0.0@ or later.
---
--- /Since: 2/
+-- | /Since: 2/
 instance TextShow (f a) => TextShow (Alt f a) where
     showbPrec = $(makeShowbPrec ''Alt)
 
--- | Only available with @base-4.8.0.0@ or later.
---
--- /Since: 2/
+-- | /Since: 2/
 $(deriveTextShow1 ''Alt)
-#endif
 
 #if MIN_VERSION_base(4,12,0)
 -- | Only available with @base-4.12.0.0@ or later.
