@@ -1,13 +1,8 @@
-{-# LANGUAGE CPP             #-}
 {-# LANGUAGE GADTs           #-}
+{-# LANGUAGE PolyKinds       #-}
 {-# LANGUAGE TemplateHaskell #-}
 {-# LANGUAGE TypeOperators   #-}
-
-#if __GLASGOW_HASKELL__ >= 706
-{-# LANGUAGE PolyKinds       #-}
-#endif
-
-{-# OPTIONS_GHC -fno-warn-orphans #-}
+{-# OPTIONS_GHC -Wno-orphans #-}
 {-|
 Module:      TextShow.Data.Type.Equality
 Copyright:   (C) 2014-2017 Ryan Scott
@@ -17,7 +12,6 @@ Stability:   Provisional
 Portability: GHC
 
 'TextShow' instance for propositional equality.
-Only provided if using @base-4.7.0.0@ or later.
 
 /Since: 2/
 -}
@@ -38,7 +32,6 @@ instance TextShow1 ((:~:) a) where
 -- | /Since: 2/
 $(deriveTextShow2 ''(:~:))
 
-#if MIN_VERSION_base(4,9,0)
 -- | /Since: 3.6/
 $(deriveTextShow ''(:~~:))
 
@@ -48,4 +41,3 @@ instance TextShow1 ((:~~:) a) where
 
 -- | /Since: 3.6/
 $(deriveTextShow2 ''(:~~:))
-#endif
