@@ -1,6 +1,6 @@
 {-# LANGUAGE CPP       #-}
 {-# LANGUAGE MagicHash #-}
-{-# OPTIONS_GHC -fno-warn-orphans #-}
+{-# OPTIONS_GHC -Wno-orphans #-}
 {-|
 Module:      TextShow.Foreign.Ptr
 Copyright:   (C) 2014-2017 Ryan Scott
@@ -16,7 +16,7 @@ Foreign Function Interface (FFI).
 -}
 module TextShow.Foreign.Ptr () where
 
-import Data.Semigroup.Compat (mtimesDefault)
+import Data.Semigroup (mtimesDefault)
 import Data.Text.Lazy.Builder (Builder, singleton)
 
 import Foreign.ForeignPtr (ForeignPtr)
@@ -24,7 +24,7 @@ import Foreign.Ptr (FunPtr, IntPtr, WordPtr, castFunPtrToPtr)
 
 import GHC.Exts (addr2Int#, int2Word#)
 import GHC.ForeignPtr (unsafeForeignPtrToPtr)
-import GHC.Num (wordToInteger)
+import GHC.Num
 import GHC.Ptr (Ptr(..))
 
 import Prelude ()
@@ -45,7 +45,8 @@ instance TextShow (Ptr a) where
 
 -- | /Since: 2/
 instance TextShow1 Ptr where
-    liftShowbPrec _ _ _ (Ptr a) = padOut . showbHex $ wordToInteger (int2Word# (addr2Int# a))
+    liftShowbPrec _ _ _ (Ptr a) = padOut . showbHex $
+      integerFromWord# (int2Word# (addr2Int# a))
       where
         padOut :: Builder -> Builder
         padOut ls =
@@ -53,6 +54,10 @@ instance TextShow1 Ptr where
           <> mtimesDefault (max 0 $ 2*SIZEOF_HSPTR - lengthB ls) (singleton '0')
           <> ls
 
+#if !(MIN_VERSION_base(4,15,0))
+        integerFromWord# = wordToInteger
+#endif
+
 -- | /Since: 2/
 instance TextShow (FunPtr a) where
     showbPrec = liftShowbPrec undefined undefined
