@@ -1,9 +1,6 @@
 {-# LANGUAGE CPP               #-}
-
-#if MIN_VERSION_base(4,8,0)
 {-# LANGUAGE TemplateHaskell   #-}
-{-# OPTIONS_GHC -fno-warn-orphans #-}
-#endif
+{-# OPTIONS_GHC -Wno-orphans #-}
 {-|
 Module:      TextShow.GHC.RTS.Flags
 Copyright:   (C) 2014-2017 Ryan Scott
@@ -13,14 +10,17 @@ Stability:   Provisional
 Portability: GHC
 
 'TextShow' instances for data types in the 'GHC.RTS.Flags' module.
-Only provided if using @base-4.8.0.0@ or later.
 
 /Since: 2/
 -}
 module TextShow.GHC.RTS.Flags () where
 
-#if MIN_VERSION_base(4,8,0)
 import GHC.RTS.Flags
+#if MIN_VERSION_base(4,21,0)
+import qualified GHC.IO.SubSystem as SubSystem
+#elif MIN_VERSION_base(4,15,0)
+import qualified GHC.RTS.Flags as SubSystem
+#endif
 
 import TextShow.Data.Bool     ()
 import TextShow.Data.Char     ()
@@ -45,10 +45,14 @@ $(deriveTextShow doTraceTypeName)
 $(deriveTextShow ''GCFlags)
 -- | /Since: 2/
 $(deriveTextShow ''ConcFlags)
-# if MIN_VERSION_base(4,15,0)
+#if MIN_VERSION_base(4,15,0)
 -- | /Since: 3.9/
-$(deriveTextShow ''IoSubSystem)
-# endif
+$(deriveTextShow ''SubSystem.IoSubSystem)
+#endif
+#if MIN_VERSION_base(4,21,0)
+-- | /Since: 3.11/
+$(deriveTextShow ''IoManagerFlag)
+#endif
 -- | /Since: 2/
 $(deriveTextShow ''MiscFlags)
 -- | /Since: 2/
@@ -61,18 +65,17 @@ $(deriveTextShow ''ProfFlags)
 $(deriveTextShow ''TraceFlags)
 -- | /Since: 2/
 $(deriveTextShow ''TickyFlags)
-# if MIN_VERSION_base(4,10,0)
+#if MIN_VERSION_base(4,10,0)
 -- | Only available with @base-4.10.0.0@ or later.
 --
 -- /Since: 3.3/
 $(deriveTextShow ''ParFlags)
-# endif
-# if MIN_VERSION_base(4,20,0)
+#endif
+#if MIN_VERSION_base(4,20,0)
 -- | Only available with @base-4.20.0.0@ or later.
 --
 -- /Since: 3.10.5/
 $(deriveTextShow ''HpcFlags)
-# endif
+#endif
 -- | /Since: 2/
 $(deriveTextShow ''RTSFlags)
-#endif
