@@ -1,9 +1,6 @@
 {-# LANGUAGE CPP             #-}
-
-#if MIN_VERSION_base(4,8,1)
 {-# LANGUAGE TemplateHaskell #-}
-{-# OPTIONS_GHC -fno-warn-orphans #-}
-#endif
+{-# OPTIONS_GHC -Wno-orphans #-}
 {-|
 Module:      TextShow.GHC.Stack
 Copyright:   (C) 2014-2017 Ryan Scott
@@ -13,21 +10,14 @@ Stability:   Provisional
 Portability: GHC
 
 'TextShow' instances for 'CallStack' and 'SrcLoc' values.
-Only provided if using @base-4.8.1.0@ or later.
 
 /Since: 3.0.1/
 -}
 module TextShow.GHC.Stack () where
 
-#if MIN_VERSION_base(4,8,1)
-import GHC.Stack (CallStack)
-# if MIN_VERSION_base(4,9,0)
-import GHC.Stack (SrcLoc, getCallStack)
-import TextShow.Classes (TextShow(..))
-# else
-import GHC.SrcLoc (SrcLoc)
-# endif
+import GHC.Stack (CallStack, SrcLoc, getCallStack)
 
+import TextShow.Classes (TextShow(..))
 import TextShow.Data.Char     ()
 import TextShow.Data.Integral ()
 import TextShow.Data.List     ()
@@ -37,13 +27,7 @@ import TextShow.TH.Internal (deriveTextShow)
 -- | /Since: 3.0.1/
 $(deriveTextShow ''SrcLoc)
 
-# if MIN_VERSION_base(4,9,0)
 -- | /Since: 3.0.1/
 instance TextShow CallStack where
     showb = showb . getCallStack
     {-# INLINE showb #-}
-# else
--- | /Since: 3.0.1/
-$(deriveTextShow ''CallStack)
-# endif
-#endif
