@@ -1,9 +1,5 @@
-{-# LANGUAGE CPP             #-}
-
-#if MIN_VERSION_base(4,8,0)
 {-# LANGUAGE TemplateHaskell #-}
-{-# OPTIONS_GHC -fno-warn-orphans #-}
-#endif
+{-# OPTIONS_GHC -Wno-orphans #-}
 {-|
 Module:      TextShow.GHC.StaticPtr
 Copyright:   (C) 2014-2017 Ryan Scott
@@ -13,13 +9,11 @@ Stability:   Provisional
 Portability: GHC
 
 'TextShow' instance for 'StaticPtrInfo'.
-Only provided if using @base-4.8.0.0@ or later.
 
 /Since: 2/
 -}
 module TextShow.GHC.StaticPtr () where
 
-#if MIN_VERSION_base(4,8,0)
 import GHC.StaticPtr (StaticPtrInfo)
 
 import TextShow.Data.Char     ()
@@ -30,4 +24,3 @@ import TextShow.TH.Internal (deriveTextShow)
 
 -- | /Since: 2/
 $(deriveTextShow ''StaticPtrInfo)
-#endif
