@@ -1,8 +1,6 @@
 {-# LANGUAGE CPP       #-}
-#if MIN_VERSION_base(4,8,0)
 {-# LANGUAGE MagicHash #-}
-#endif
-{-# OPTIONS_GHC -fno-warn-orphans #-}
+{-# OPTIONS_GHC -Wno-orphans #-}
 {-|
 Module:      TextShow.Numeric.Natural
 Copyright:   (C) 2014-2017 Ryan Scott
@@ -17,12 +15,16 @@ Portability: GHC
 -}
 module TextShow.Numeric.Natural () where
 
-#if MIN_VERSION_base(4,8,0)
+#if MIN_VERSION_base(4,15,0)
+import GHC.Exts (Word(..))
+import GHC.Num (integerFromNatural)
+import GHC.Num.Natural (Natural(..))
+#elif defined(MIN_VERSION_integer_gmp)
+import GHC.Exts (Word(..))
 import GHC.Integer.GMP.Internals (Integer(..))
 import GHC.Natural (Natural(..))
-import GHC.Types (Word(..))
 #else
-import Numeric.Natural.Compat (Natural)
+import Numeric.Natural (Natural)
 #endif
 
 import TextShow.Classes (TextShow(..))
@@ -30,7 +32,10 @@ import TextShow.Data.Integral ()
 
 -- | /Since: 2/
 instance TextShow Natural where
-#if MIN_VERSION_base(4,8,0)
+#if MIN_VERSION_base(4,15,0)
+    showbPrec p (NS w) = showbPrec p (W# w)
+    showbPrec p n      = showbPrec p (integerFromNatural n)
+#elif defined(MIN_VERSION_integer_gmp)
     showbPrec _ (NatS# w#)  = showb $ W# w#
     showbPrec p (NatJ# bn)  = showbPrec p $ Jp# bn
 #else
