@@ -1,13 +1,10 @@
 {-# LANGUAGE CPP             #-}
+{-# LANGUAGE DataKinds       #-}
 {-# LANGUAGE DeriveGeneric   #-}
 {-# LANGUAGE MagicHash       #-}
 {-# LANGUAGE TemplateHaskell #-}
 {-# LANGUAGE TypeFamilies    #-}
 
-#if __GLASGOW_HASKELL__ >= 706
-{-# LANGUAGE DataKinds       #-}
-#endif
-
 {-|
 Module:      Derived.MagicHash
 Copyright:   (C) 2014-2017 Ryan Scott
@@ -25,14 +22,8 @@ module Derived.MagicHash (
 #endif
   ) where
 
-#if __GLASGOW_HASKELL__ < 711
-import qualified Generics.Deriving.TH as Generics
-#endif
-
 import           GHC.Exts
-#if __GLASGOW_HASKELL__ >= 711
 import           GHC.Generics (Generic, Generic1)
-#endif
 
 import           Instances.Utils.GenericArbitrary (genericArbitrary)
 
@@ -41,10 +32,8 @@ import           Prelude.Compat
 
 import           Test.QuickCheck (Arbitrary(..))
 
-import           Text.Show.Deriving (deriveShow1Options, legacyShowOptions)
-#if defined(NEW_FUNCTOR_CLASSES)
-import           Text.Show.Deriving (deriveShow2Options)
-#endif
+import           Text.Show.Deriving (deriveShow1Options, deriveShow2Options,
+                                     legacyShowOptions)
 
 import           TextShow.TH (deriveTextShow, deriveTextShow1, deriveTextShow2)
 -------------------------------------------------------------------------------
@@ -58,10 +47,8 @@ data TyCon# a b = TyCon# {
   , tcChar#   :: Char#
   , tcWord#   :: Word#
 } deriving ( Show
-#if __GLASGOW_HASKELL__ >= 711
            , Generic
            , Generic1
-#endif
            )
 
 #if MIN_VERSION_base(4,13,0)
@@ -72,6 +59,10 @@ data TyCon'# a b = TyCon'# {
   , tcInt16#  :: Int16#
   , tcWord8#  :: Word8#
   , tcWord16# :: Word16#
+# if MIN_VERSION_base(4,16,0)
+  , tcInt32#  :: Int32#
+  , tcWord32# :: Word32#
+# endif
 } deriving Show
 #endif
 
@@ -88,10 +79,8 @@ data instance TyFamily# a b = TyFamily# {
   , tfChar#   :: Char#
   , tfWord#   :: Word#
 } deriving ( Show
-#if __GLASGOW_HASKELL__ >= 711
            , Generic
            , Generic1
-#endif
            )
 
 #if MIN_VERSION_base(4,13,0)
@@ -104,6 +93,10 @@ data instance TyFamily'# a b = TyFamily'# {
   , tfInt16#  :: Int16#
   , tfWord8#  :: Word8#
   , tfWord16# :: Word16#
+# if MIN_VERSION_base(4,16,0)
+  , tfInt32#  :: Int32#
+  , tfWord32# :: Word32#
+# endif
 } deriving Show
 #endif
 
@@ -124,8 +117,15 @@ instance (Arbitrary a, Arbitrary b) => Arbitrary (TyCon'# a b) where
       I# i2 <- arbitrary
       W# w1 <- arbitrary
       W# w2 <- arbitrary
-      pure $ TyCon'# a b (narrowInt8# i1)  (narrowInt16# i2)
-                         (narrowWord8# w1) (narrowWord16# w2)
+# if MIN_VERSION_base(4,16,0)
+      I# i3 <- arbitrary
+      W# w3 <- arbitrary
+# endif
+      pure $ TyCon'# a b (intToInt8Compat# i1)   (intToInt16Compat# i2)
+                         (wordToWord8Compat# w1) (wordToWord16Compat# w2)
+# if MIN_VERSION_base(4,16,0)
+                         (intToInt32# i3)        (wordToWord32# w3)
+# endif
 
 instance (Arbitrary a, Arbitrary b) => Arbitrary (TyFamily'# a b) where
     arbitrary = do
@@ -135,40 +135,58 @@ instance (Arbitrary a, Arbitrary b) => Arbitrary (TyFamily'# a b) where
       I# i2 <- arbitrary
       W# w1 <- arbitrary
       W# w2 <- arbitrary
-      pure $ TyFamily'# a b (narrowInt8# i1)  (narrowInt16# i2)
-                            (narrowWord8# w1) (narrowWord16# w2)
+# if MIN_VERSION_base(4,16,0)
+      I# i3 <- arbitrary
+      W# w3 <- arbitrary
+# endif
+      pure $ TyFamily'# a b (intToInt8Compat# i1)   (intToInt16Compat# i2)
+                            (wordToWord8Compat# w1) (wordToWord16Compat# w2)
+# if MIN_VERSION_base(4,16,0)
+                            (intToInt32# i3)        (wordToWord32# w3)
+# endif
+
+# if MIN_VERSION_base(4,16,0)
+intToInt8Compat# :: Int# -> Int8#
+intToInt8Compat# = intToInt8#
+
+intToInt16Compat# :: Int# -> Int16#
+intToInt16Compat# = intToInt16#
+
+wordToWord8Compat# :: Word# -> Word8#
+wordToWord8Compat# = wordToWord8#
+
+wordToWord16Compat# :: Word# -> Word16#
+wordToWord16Compat# = wordToWord16#
+# else
+intToInt8Compat# :: Int# -> Int8#
+intToInt8Compat# = narrowInt8#
+
+intToInt16Compat# :: Int# -> Int16#
+intToInt16Compat# = narrowInt16#
+
+wordToWord8Compat# :: Word# -> Word8#
+wordToWord8Compat# = narrowWord8#
+
+wordToWord16Compat# :: Word# -> Word16#
+wordToWord16Compat# = narrowWord16#
+# endif
 #endif
 
 -------------------------------------------------------------------------------
 
 $(deriveShow1Options legacyShowOptions ''TyCon#)
-#if defined(NEW_FUNCTOR_CLASSES)
-$(deriveShow2Options legacyShowOptions ''TyCon#)
-#endif
 
 $(deriveTextShow  ''TyCon#)
 $(deriveTextShow1 ''TyCon#)
 $(deriveTextShow2 ''TyCon#)
 
-#if __GLASGOW_HASKELL__ < 711
-$(Generics.deriveAll0And1 ''TyCon#)
-#endif
-
-#if !defined(NEW_FUNCTOR_CLASSES)
-$(deriveShow1Options legacyShowOptions 'TyFamily#)
-#else
 $(deriveShow1Options legacyShowOptions 'TyFamily#)
 $(deriveShow2Options legacyShowOptions 'TyFamily#)
-#endif
 
 $(deriveTextShow  'TyFamily#)
 $(deriveTextShow1 'TyFamily#)
 $(deriveTextShow2 'TyFamily#)
 
-#if __GLASGOW_HASKELL__ < 711
-$(Generics.deriveAll0And1 'TyFamily#)
-#endif
-
 #if MIN_VERSION_base(4,13,0)
 $(deriveShow1Options legacyShowOptions ''TyCon'#)
 $(deriveShow2Options legacyShowOptions ''TyCon'#)
