@@ -1,6 +1,6 @@
 {-# LANGUAGE CPP                #-}
 {-# LANGUAGE StandaloneDeriving #-}
-{-# OPTIONS_GHC -fno-warn-orphans #-}
+{-# OPTIONS_GHC -Wno-orphans #-}
 
 {-|
 Module:      Instances.GHC.Event
@@ -14,28 +14,21 @@ Portability: GHC
 -}
 module Instances.GHC.Event () where
 
-#if !defined(__GHCJS__) && !defined(mingw32_HOST_OS)
-import GHC.Event (Event, evtRead, evtWrite)
+#if !defined(__GHCJS__) && !defined(ghcjs_HOST_OS) && !defined(mingw32_HOST_OS)
+import GHC.Event (Event, Lifetime(..), evtRead, evtWrite)
 
 import Prelude ()
 import Prelude.Compat
 
-import Test.QuickCheck (Arbitrary(..), oneof)
-
-# if MIN_VERSION_base(4,8,1)
-import GHC.Event (Lifetime(..))
-import Test.QuickCheck (arbitraryBoundedEnum)
-# endif
+import Test.QuickCheck (Arbitrary(..), arbitraryBoundedEnum, oneof)
 
 instance Arbitrary Event where
     arbitrary = oneof $ map pure [evtRead, evtWrite]
 
 -- TODO: instance Arbitrary FdKey
 
-# if MIN_VERSION_base(4,8,1)
 deriving instance Bounded Lifetime
 deriving instance Enum Lifetime
 instance Arbitrary Lifetime where
     arbitrary = arbitraryBoundedEnum
-# endif
 #endif
