@@ -1,16 +1,14 @@
 {-# LANGUAGE CPP                  #-}
-
-#if MIN_VERSION_base(4,8,0)
 {-# LANGUAGE DataKinds            #-}
 {-# LANGUAGE FlexibleInstances    #-}
+{-# LANGUAGE StandaloneDeriving   #-}
 {-# LANGUAGE TemplateHaskell      #-}
 {-# LANGUAGE TypeFamilies         #-}
 {-# LANGUAGE TypeSynonymInstances #-}
-{-# OPTIONS_GHC -fno-warn-orphans #-}
-# if __GLASGOW_HASKELL__ == 802
+{-# OPTIONS_GHC -Wno-orphans #-}
+#if __GLASGOW_HASKELL__ == 802
 -- See Note [Increased simpl-tick-factor on old GHCs] in TextShow.Data.Complex
 {-# OPTIONS_GHC -fsimpl-tick-factor=200 #-}
-# endif
 #endif
 
 {-|
@@ -23,11 +21,8 @@ Portability: GHC
 
 'Arbitrary' instances for data types in the "GHC.RTS.Flags" module.
 -}
-module Instances.GHC.RTS.Flags (
-#if !(MIN_VERSION_base(4,8,0))
-    ) where
-#else
-      GiveGCStats'
+module Instances.GHC.RTS.Flags
+    ( GiveGCStats'
     , DoCostCentres'
     , DoHeapProfile'
     , DoTrace'
@@ -35,9 +30,17 @@ module Instances.GHC.RTS.Flags (
 
 import qualified Generics.Deriving.TH as Generics (deriveAll0)
 import           GHC.RTS.Flags
+#if MIN_VERSION_base(4,21,0)
+import qualified GHC.IO.SubSystem as SubSystem
+#elif MIN_VERSION_base(4,15,0)
+import qualified GHC.RTS.Flags as SubSystem
+#endif
 import           Instances.Utils.GenericArbitrary (genericArbitrary)
 import           Language.Haskell.TH.Lib (conT)
 import           Test.QuickCheck (Arbitrary(..))
+#if MIN_VERSION_base(4,21,0)
+import           Test.QuickCheck (arbitraryBoundedEnum)
+#endif
 import           TextShow.TH.Names
 
 #if !(MIN_VERSION_base(4,15,0))
@@ -61,7 +64,7 @@ $(Generics.deriveAll0 doTraceTypeName)
 #endif
 
 #if MIN_VERSION_base(4,15,0)
-$(Generics.deriveAll0 ''IoSubSystem)
+$(Generics.deriveAll0 ''SubSystem.IoSubSystem)
 #endif
 
 instance Arbitrary RTSFlags where
@@ -74,10 +77,16 @@ instance Arbitrary ConcFlags where
     arbitrary = genericArbitrary
 
 #if MIN_VERSION_base(4,15,0)
-instance Arbitrary IoSubSystem where
+instance Arbitrary SubSystem.IoSubSystem where
     arbitrary = genericArbitrary
 #endif
 
+#if MIN_VERSION_base(4,21,0)
+deriving instance Bounded IoManagerFlag
+instance Arbitrary IoManagerFlag where
+    arbitrary = arbitraryBoundedEnum
+#endif
+
 instance Arbitrary MiscFlags where
     arbitrary = genericArbitrary
 
@@ -96,15 +105,15 @@ instance Arbitrary TraceFlags where
 instance Arbitrary TickyFlags where
     arbitrary = genericArbitrary
 
-# if MIN_VERSION_base(4,10,0)
+#if MIN_VERSION_base(4,10,0)
 instance Arbitrary ParFlags where
     arbitrary = genericArbitrary
-# endif
+#endif
 
-# if MIN_VERSION_base(4,20,0)
+#if MIN_VERSION_base(4,20,0)
 instance Arbitrary HpcFlags where
     arbitrary = genericArbitrary
-# endif
+#endif
 
 type GiveGCStats'   = $(conT giveGCStatsTypeName)
 type DoCostCentres' = $(conT doCostCentresTypeName)
@@ -122,4 +131,3 @@ instance Arbitrary DoHeapProfile' where
 
 instance Arbitrary DoTrace' where
     arbitrary = genericArbitrary
-#endif
