@@ -13,9 +13,7 @@ Portability: GHC
 module Spec.Data.MonoidSpec (main, spec) where
 
 import Data.Monoid
-import Data.Proxy.Compat (Proxy(..))
-
-import Generics.Deriving.Instances ()
+import Data.Proxy (Proxy(..))
 
 import Instances.Data.Monoid ()
 
@@ -68,14 +66,12 @@ spec = parallel $ do
         matchesTextShowSpec  p
         genericTextShowSpec  p
         genericTextShow1Spec p
-#if MIN_VERSION_base(4,8,0)
     describe "Alt Maybe Int" $ do
         let p :: Proxy (Alt Maybe Int)
             p = Proxy
         matchesTextShowSpec  p
         genericTextShowSpec  p
         genericTextShow1Spec p
-#endif
 #if MIN_VERSION_base(4,12,0)
     describe "Ap Maybe Int" $ do
         let p :: Proxy (Ap Maybe Int)
