@@ -19,13 +19,10 @@ import Prelude.Compat
 
 import Test.Hspec (Spec, hspec, parallel)
 
-#if !defined(__GHCJS__) && !defined(mingw32_HOST_OS)
-import Data.Proxy.Compat (Proxy(..))
+#if !defined(__GHCJS__) && !defined(ghcjs_HOST_OS) && !defined(mingw32_HOST_OS)
+import Data.Proxy (Proxy(..))
 
-import GHC.Event (Event)
-# if MIN_VERSION_base(4,8,1)
-import GHC.Event (Lifetime)
-#endif
+import GHC.Event (Event, Lifetime)
 
 import Spec.Utils (matchesTextShowSpec)
 
@@ -38,15 +35,13 @@ main = hspec spec
 
 spec :: Spec
 spec = parallel $ do
-#if !defined(__GHCJS__) && !defined(mingw32_HOST_OS)
+#if !defined(__GHCJS__) && !defined(ghcjs_HOST_OS) && !defined(mingw32_HOST_OS)
     describe "Event" $
         matchesTextShowSpec (Proxy :: Proxy Event)
 --     describe "FdKey" $
 --         matchesTextShowSpec (Proxy :: Proxy FdKey)
-# if MIN_VERSION_base(4,8,1)
     describe "Lifetime" $
         matchesTextShowSpec (Proxy :: Proxy Lifetime)
-# endif
 #else
     pure ()
 #endif
