@@ -1,5 +1,3 @@
-{-# LANGUAGE CPP #-}
-
 {-|
 Module:      Spec.GHC.StackSpec
 Copyright:   (C) 2014-2017 Ryan Scott
@@ -12,37 +10,25 @@ Portability: GHC
 -}
 module Spec.GHC.StackSpec (main, spec) where
 
+import Data.Proxy (Proxy(..))
+
+import GHC.Stack (CallStack, SrcLoc)
+
 import Instances.GHC.Stack ()
 
 import Prelude ()
 import Prelude.Compat
 
-import Test.Hspec (Spec, hspec, parallel)
-
-#if MIN_VERSION_base(4,8,1)
-import Data.Proxy.Compat (Proxy(..))
-import GHC.Stack (CallStack)
-# if MIN_VERSION_base(4,9,0)
-import GHC.Stack (SrcLoc)
-# else
-import GHC.SrcLoc (SrcLoc)
-# endif
-
 import Spec.Utils (matchesTextShowSpec)
 
-import Test.Hspec (describe)
-#endif
+import Test.Hspec (Spec, describe, hspec, parallel)
 
 main :: IO ()
 main = hspec spec
 
 spec :: Spec
 spec = parallel $ do
-#if MIN_VERSION_base(4,8,1)
     describe "CallStack" $
         matchesTextShowSpec (Proxy :: Proxy CallStack)
     describe "SrcLoc" $
         matchesTextShowSpec (Proxy :: Proxy SrcLoc)
-#else
-    pure ()
-#endif
